<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Get the orderid and userid parameters from the request URL
$orderid = $_GET['orderid'];
$userid = $_GET['userid'];
$otp = $_GET['otp'];

// Connect to the database
include '../../config/database2.php';

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Check if the order has already been picked
$stmt = $conn->prepare("SELECT Delivered, CustomerID FROM `Orders` WHERE OrderID = ?");
$stmt->bind_param("i", $orderid);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows == 0) {
    // If the order does not exist, return an error message
    $response = ["error" => "Order does not exist"];
} else {
    $row = $result->fetch_assoc();
    if ($row['Delivered'] == 1) {
        // If the order has already been picked, return an error message
        $response = ["error" => "Order already Delivered, try another order"];
    } else {
        // Retrieve the customer's OTP from the Customer table
        $stmt = $conn->prepare("SELECT OTP FROM `customer` WHERE ID = ?");
        $stmt->bind_param("i", $row['CustomerID']);
        $stmt->execute();
        $result2 = $stmt->get_result();
        $row2 = $result2->fetch_assoc();
        $customer_otp = $row2['OTP'];

        // Compare the customer's OTP with the OTP entered by the customer
        if ($otp != $customer_otp) {
            // If the OTPs don't match, return an error message
            $response = ["error" => "customer OTP does not match"];
        } else {
            // Otherwise, update the order and insert a new row into the order_user table
            $stmt = $conn->prepare("UPDATE `Orders` SET Delivered = 1, DeliveredTime = NOW() WHERE OrderID = ?");
            $stmt->bind_param("i", $orderid);
            $stmt->execute();

            $stmt = $conn->prepare("INSERT INTO order_user (OrderID,date_time, user_id, action) VALUES ($orderid,NOW(), ?, 'deliver')");
            $stmt->bind_param("i", $userid);
            $stmt->execute();

            $response = ["success" => true];
        }
    }
}

// Return the response as a JSON object
echo json_encode($response);

$conn->close();
?>
