<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");
header("Access-Control-Allow-Credentials: true");

// Connect to the database
include '../config/database3.php';
include '../config/url.php';

// Validate the API key
$expected_api_key = "8L14irhDOhBUffrmiv2kqUSoSpeIK9D7JYDmsPVS9-M";

$received_api_key = isset($_SERVER['HTTP_AUTH']) ? trim($_SERVER['HTTP_AUTH']) : '';

if ($received_api_key !== $expected_api_key) {
    $response = [
        'success' => false,
        'message' => "Invalid API Key."
    ];
    echo json_encode($response);
    exit; // Terminate the script if the API key is invalid
}

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}



// Pagination parameters
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Get the requested page, default is 1
$itemsPerPage = 12;
$offset = ($page - 1) * $itemsPerPage;


$sql = "SELECT 
    item.ID AS itemID, 
    item.ItemLookupCode,
    item.BinLocation,
    item.Description,
    item.DepartmentID,
    item.CategoryID,
    item.quantity as Quantity,
    item.Price, 
    item.StoreID as InventoryLocation,
    'product' AS type,
    CONCAT('$url', productimages.pic1) AS imageUrl,
    CASE 
        WHEN item.SerialNumberCount IS NOT NULL AND item.SerialNumberCount > 0 THEN 1
        ELSE 0
    END AS is_serial,
    CASE 
            WHEN item.Inactive = 0 THEN 'Active'
            WHEN item.Inactive = 1 THEN 'Inactive'
            ELSE 'Unknown'
        END AS status
    
FROM 
    item
    
LEFT JOIN 
    productimages ON item.ID = productimages.itemID

WHERE 
    item.quantity > 0
    AND item.Inactive = 0
    AND item.featured = 1
    
ORDER BY 
    productimages.pic1 IS NOT NULL DESC, item.updated_at DESC";



$stmt = $conn->prepare($sql);
$stmt->execute();
$result = $stmt->get_result();

// Count the total rows
$totalCount = $result->num_rows;

// Now you can fetch the items with pagination
$sqlWithLimit = $sql . " LIMIT ?,?";
$stmtWithLimit = $conn->prepare($sqlWithLimit);
$stmtWithLimit->bind_param('ii',$offset, $itemsPerPage);
$stmtWithLimit->execute();
$resultWithLimit = $stmtWithLimit->get_result();
$items = $resultWithLimit->fetch_all(MYSQLI_ASSOC);


// Prepare the response data
$response = [
    'total_pages' => ceil($totalCount / $itemsPerPage),
    'current_page' => $page,
    'total_items' => $totalCount,
    'items' => $items
];

// Return the API response
echo json_encode($response);

$conn->close();
?>

